@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class LogisticsConfig(AppConfig):
-    name = 'revpayment.logistics'
-    label = 'revpayment.logistics'
+    name = "revpayment.logistics"
+    label = "revpayment.logistics"
