@@ -1,38 +1,48 @@
 from django.conf import settings
 from django.utils.module_loading import import_string
 
-
 DEFAULTS = {
     # Base API policies
-    'DEBUG': True,
-    'PAYMENT_VERSION': 'v3',
-    'TAX_RATE': 0.05,
-    'LOGISTIC_SENDER_NAME': '',
-    'LOGISTIC_SENDER_PHONE': '',
-    'LOGISTIC_SENDER_CELLPHONE': '',
-    'ORDER_CLASS': 'revpayment.models.Order',
-    'ITEM_CLASS': 'revpayment.items.Item',
-    'CALC_CLASS': 'revpayment.calculations.Calculations',
-    'CONFIG_CLASS': 'revpayment.config.Config',
-    'HANDLER_CLASS': 'revpayment.handlers.Handler',
-    'INVOICE_CLASS': 'revpayment.invoice.models.Invoice',
-    'DEFAULT_SDK_CLASS': 'revpayment.checkout.CheckoutSDK',
-    'DEFAULT_CART_CLASS': 'revpayment.carts.Cart',
-    'DEFAULT_NEWEB_CLASS': 'revpayment.payments.NewebPayment',
-    'DEFAULT_ECPAY_CLASS': 'revpayment.payments.EcpayPayment',
-    'DEFAULT_CREDIT_CLASS': 'revpayment.payments.CreditPayment',
-    'DEFAULT_REDIRECT_URL': f'{settings.WEB_HOST}/order',
-    'DEFAULT_CHECKOUTFAIL_URL': f'{settings.WEB_HOST}/cart',
-    'DEFAULT_REDIRECT_QUERY': 'id'
+    "DEBUG": True,
+    "PAYMENT_VERSION": "v3",
+    "TAX_RATE": 0.05,
+    "LOGISTIC_SENDER_NAME": "",
+    "LOGISTIC_SENDER_PHONE": "",
+    "LOGISTIC_SENDER_CELLPHONE": "",
+    "ORDER_CLASS": "revpayment.models.Order",
+    "ITEM_CLASS": "revpayment.items.Item",
+    "CALC_CLASS": "revpayment.calculations.Calculations",
+    "CONFIG_CLASS": "revpayment.config.Config",
+    "HANDLER_CLASS": "revpayment.handlers.Handler",
+    "INVOICE_CLASS": "revpayment.invoice.models.Invoice",
+    "DEFAULT_SDK_CLASS": "revpayment.checkout.CheckoutSDK",
+    "DEFAULT_CART_CLASS": "revpayment.carts.Cart",
+    "DEFAULT_NEWEB_CLASS": "revpayment.payments.NewebPayment",
+    "DEFAULT_ECPAY_CLASS": "revpayment.payments.EcpayPayment",
+    "DEFAULT_CREDIT_CLASS": "revpayment.payments.CreditPayment",
+    "DEFAULT_REDIRECT_URL": f"{settings.WEB_HOST}/order",
+    "DEFAULT_CHECKOUTFAIL_URL": f"{settings.WEB_HOST}/cart",
+    "DEFAULT_REDIRECT_QUERY": "id",
 }
 
 
 # List of settings that may be in string import notation.
 IMPORT_STRINGS = [
-    'ORDER_CLASS', 'ITEM_CLASS', 'CALC_CLASS', 'CONFIG_CLASS', 'HANDLER_CLASS',
-    'INVOICE_CLASS', 'BUYER_CLASS', 'PRODUCT_CLASS', 'PRODUCT_SERIALIZER_CLASS',
-    'VERIFY_METHOD', 'DEFAULT_SDK_CLASS', 'DEFAULT_CART_CLASS', 'DEFAULT_NEWEB_CLASS',
-    'DEFAULT_ECPAY_CLASS', 'DEFAULT_CREDIT_CLASS',
+    "ORDER_CLASS",
+    "ITEM_CLASS",
+    "CALC_CLASS",
+    "CONFIG_CLASS",
+    "HANDLER_CLASS",
+    "INVOICE_CLASS",
+    "BUYER_CLASS",
+    "PRODUCT_CLASS",
+    "PRODUCT_SERIALIZER_CLASS",
+    "VERIFY_METHOD",
+    "DEFAULT_SDK_CLASS",
+    "DEFAULT_CART_CLASS",
+    "DEFAULT_NEWEB_CLASS",
+    "DEFAULT_ECPAY_CLASS",
+    "DEFAULT_CREDIT_CLASS",
 ]
 
 
@@ -57,7 +67,12 @@ def import_from_string(val, setting_name):
     try:
         return import_string(val)
     except ImportError as e:
-        msg = "Could not import '%s' for API setting '%s'. %s: %s." % (val, setting_name, e.__class__.__name__, e)
+        msg = "Could not import '%s' for API setting '%s'. %s: %s." % (
+            val,
+            setting_name,
+            e.__class__.__name__,
+            e,
+        )
         raise ImportError(msg)
 
 
@@ -68,7 +83,7 @@ class APISettings:
 
     @property
     def user_settings(self):
-        return getattr(settings, 'REVPAYMENT', {})
+        return getattr(settings, "REVPAYMENT", {})
 
     def __getattr__(self, attr):
         try:
